import request from '@/utils/request'

// 查询玛氏岗位列表
export function listUnit(query) {
  return request({
    url: '/iscs/unit/getIsUnitPage',
    method: 'get',
    params: query
  })
}


// 查询玛氏岗位详细
export function getUnitInfo(deptId) {
  return request({
    url: '/iscs/unit/selectIsUnitById?unitId=' + deptId,
    method: 'get'
  })
}


// 新增玛氏岗位
export function addUnit(data) {
  return request({
    url: '/iscs/unit/insertIsUnit',
    method: 'post',
    data: data
  })
}

// 修改玛氏岗位
export function updateUnit(data) {
  return request({
    url: '/iscs/unit/updateIsUnit',
    method: 'post',
    data: data
  })
}

// 删除玛氏岗位
export function delUnit(deptId) {
  return request({
    url: '/iscs/unit/deleteIsUnitByUnitIds?unitIds=' + deptId,
    method: 'post'
  })
}
